@@ -122,6 +122,7 @@ void EmailAddressSelectionWidget::Private::init()
     layout->addLayout(searchLayout);
 
     mView = new Akonadi::EntityTreeView;
+    mView->setEditTriggers(Akonadi::EntityTreeView::NoEditTriggers);
 
     QLabel *label = new QLabel(i18nc("@label Search in a list of contacts", "Search:"));
     mSearchLine = new SearchLineEdit(mView);
@@ -156,7 +157,11 @@ void EmailAddressSelectionWidget::Private::init()
 
     mSearchLine->setFocus();
 
-    QTimer::singleShot(1000, mView, &QTreeView::expandAll);
+    if (Akonadi::EntityTreeModel *etm = qobject_cast<Akonadi::EntityTreeModel*>(mModel)) {
+        QObject::connect(etm, &Akonadi::EntityTreeModel::collectionTreeFetched, mView, &QTreeView::expandAll);
+    } else {
+        QTimer::singleShot(1000, mView, &QTreeView::expandAll);
+    }
 }
 
 EmailAddressSelectionWidget::EmailAddressSelectionWidget(QWidget *parent)
